@@ -55,21 +55,68 @@ getMatchLabels <- function(labbcat.url, match.ids, layer.ids, target.offset=0, a
         pb <- txtProgressBar(min = 0, max = length(match.ids), style = 3)
     }
 
+    ## the API is now api/results[/upload] but used to be api/getMatchAnnotations
+    ## we might need to fall back to the old endpoint
+    deprecatedApi <- F
+
     ## break match.ids into manageable chunks
     matchIdChunks <- split(match.ids, ceiling(seq_along(match.ids)/page.length))
-    for (match.ids in matchIdChunks) {
-        write.table(match.ids, upload.file, sep=",", row.names=FALSE, col.names=TRUE)
+    for (MatchId in matchIdChunks) {
+        write.table(
+            data.frame(MatchId), upload.file, sep=",", row.names=FALSE, col.names=TRUE)
         
         ## make request
         layer.ids <- paste(layer.ids,collapse="\n")
-        parameters <- list(
-            layerIds=layer.ids,
-            targetOffset=target.offset, annotationsPerLayer=annotations.per.layer,
-            csvFieldDelimiter=",", targetColumn=0, copyColumns=include.match.ids,
-            "content-type"="text/csv",
-            plus="Token.plus.", minus="Token.minus.",
-            uploadfile=httr::upload_file(upload.file))
-        resp <- http.post.multipart(labbcat.url, "api/getMatchAnnotations", parameters, download.file)
+        if (!deprecatedApi) {
+            parameters <- list(
+                csvFieldDelimiter=",", targetColumn="MatchId", "content-type"="text/csv",
+                results=httr::upload_file(upload.file))
+            resp <- http.post.multipart(
+                labbcat.url, "api/results/upload", parameters, download.file)
+            if (httr::status_code(resp) != 404) { ## endpoint exists
+                resp.json <- jsonlite::fromJSON(
+                                           httr::content(resp, as="text", encoding="UTF-8"))
+                for (error in resp.json$errors) print(error)
+                ## we get a task ID back
+                threadId <- resp.json$model$threadId
+                ## wait for task until it finishes (should be immediate)
+                thread <- thread.get(labbcat.url, threadId)
+                if (is.null(thread)) return()
+                while (thread$running) {
+                    Sys.sleep(1)
+                    thread <- thread.get(labbcat.url, threadId)
+                    if (is.null(thread)) return()
+                } # poll until finished
+                ## export fields
+                parameters <- list(
+                    threadId=threadId,
+                    csv_layers=layer.ids,
+                    offsetThreshold="none",
+                    targetOffset=target.offset,
+                    annotationsPerLayer=annotations.per.layer,
+                    csvFieldDelimiter=",", 
+                    "content-type"="text/csv",
+                    plus="Token.plus.", minus="Token.minus.")
+                resp <- http.post(
+                    labbcat.url, "api/results", parameters, download.file)
+                
+                ## free the upload thread so it's not using server resources
+                thread.release(labbcat.url, threadId)
+            } else { ## endpoint not found
+                deprecatedApi <- T ## fall through to next block
+            }
+        } ## can fall through to below        
+        if (deprecatedApi) {
+            parameters <- list(
+                layerIds=layer.ids,
+                targetOffset=target.offset, annotationsPerLayer=annotations.per.layer,
+                csvFieldDelimiter=",", targetColumn=0, copyColumns=include.match.ids,
+                "content-type"="text/csv",
+                plus="Token.plus.", minus="Token.minus.",
+                uploadfile=httr::upload_file(upload.file))
+            resp <- http.post.multipart(
+                labbcat.url, "api/getMatchAnnotations", parameters, download.file)
+        }
         
         ## tidily remove upload file
         file.remove(upload.file)
@@ -85,6 +132,10 @@ getMatchLabels <- function(labbcat.url, match.ids, layer.ids, target.offset=0, a
 
         ## load the returned entries
         labels <- read.csv(download.file, header=T, blank.lines.skip=F, na.strings="")
+        if (!include.match.ids && !deprecatedApi) {
+            ## the entries include a MatchId column, so remove it
+            labels <- subset(labels, select=-MatchId)
+        }
         
         ## tidily remove the downloaded file
         file.remove(download.file)
