@@ -1,6 +1,6 @@
-labbcat.url <- Sys.getenv('TEST_READ_LABBCAT_URL')
-username <- Sys.getenv('TEST_READ_LABBCAT_USERNAME')
-password <- Sys.getenv('TEST_READ_LABBCAT_PASSWORD')
+labbcat.url <- Sys.getenv('TEST_ADMIN_LABBCAT_URL')
+username <- Sys.getenv('TEST_ADMIN_LABBCAT_USERNAME')
+password <- Sys.getenv('TEST_ADMIN_LABBCAT_PASSWORD')
 
 test_that("getFragmentAnnotations works with vectors", {
     skip_on_cran() # don't run tests that depend on external resource on CRAN
